import sys
import re
import os

def get_current_username():
    """Get the current system username."""
    return os.getenv("USER") or os.getenv("USERNAME") or ""

def main():
    current_user = get_current_username()
    todo_pattern = re.compile(r"\bTODO\b", re.IGNORECASE)
    user_pattern = re.compile(re.escape(current_user), re.IGNORECASE)  # Escape to match literal username

    failed_files = []

    for filename in sys.argv[1:]:
        with open(filename, "r", encoding="utf-8") as file:
            for i, line in enumerate(file, start=1):
                if todo_pattern.search(line) and user_pattern.search(line):
                    print(f"TODO with username '{current_user}' found in {filename}:{i}: {line.strip()}")
                    failed_files.append(filename)

    return 1 if failed_files else 0

if __name__ == "__main__":
    sys.exit(main())
